@@ -1,16 +1,6 @@
 '''
 # AWS CDK Assets
 
-<!--BEGIN STABILITY BANNER-->---
-
-
-![Deprecated](https://img.shields.io/badge/deprecated-critical.svg?style=for-the-badge)
-
-> This API may emit warnings. Backward compatibility is not guaranteed.
-
----
-<!--END STABILITY BANNER-->
-
 All types moved to @aws-cdk/core.
 '''
 import abc
@@ -58,6 +48,20 @@ class CopyOptions:
         :deprecated: see ``core.CopyOptions``
 
         :stability: deprecated
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import monocdk as monocdk
+            from monocdk import assets
+            
+            copy_options = assets.CopyOptions(
+                exclude=["exclude"],
+                follow=assets.FollowMode.NEVER,
+                ignore_mode=monocdk.IgnoreMode.GLOB
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if exclude is not None:
@@ -147,6 +151,21 @@ class FingerprintOptions(CopyOptions):
         :deprecated: see ``core.FingerprintOptions``
 
         :stability: deprecated
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import monocdk as monocdk
+            from monocdk import assets
+            
+            fingerprint_options = assets.FingerprintOptions(
+                exclude=["exclude"],
+                extra_hash="extraHash",
+                follow=assets.FollowMode.NEVER,
+                ignore_mode=monocdk.IgnoreMode.GLOB
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if exclude is not None:
@@ -266,10 +285,6 @@ class IAsset(typing_extensions.Protocol):
     :stability: deprecated
     '''
 
-    @builtins.staticmethod
-    def __jsii_proxy_class__() -> typing.Type["_IAssetProxy"]:
-        return _IAssetProxy
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="sourceHash")
     def source_hash(self) -> builtins.str:
@@ -307,6 +322,9 @@ class _IAssetProxy:
         '''
         return typing.cast(builtins.str, jsii.get(self, "sourceHash"))
 
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, IAsset).__jsii_proxy_class__ = lambda : _IAssetProxy
+
 
 class Staging(
     _AssetStaging_8a58c9a4,
@@ -318,6 +336,24 @@ class Staging(
     :deprecated: use ``core.AssetStaging``
 
     :stability: deprecated
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import monocdk as monocdk
+        from monocdk import assets
+        
+        staging = assets.Staging(self, "MyStaging",
+            source_path="sourcePath",
+        
+            # the properties below are optional
+            exclude=["exclude"],
+            extra_hash="extraHash",
+            follow=assets.FollowMode.NEVER,
+            ignore_mode=monocdk.IgnoreMode.GLOB
+        )
     '''
 
     def __init__(
@@ -350,7 +386,7 @@ class Staging(
             ignore_mode=ignore_mode,
         )
 
-        jsii.create(Staging, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
 
 @jsii.data_type(
@@ -385,6 +421,24 @@ class StagingProps(FingerprintOptions):
         :deprecated: use ``core.AssetStagingProps``
 
         :stability: deprecated
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import monocdk as monocdk
+            from monocdk import assets
+            
+            staging_props = assets.StagingProps(
+                source_path="sourcePath",
+            
+                # the properties below are optional
+                exclude=["exclude"],
+                extra_hash="extraHash",
+                follow=assets.FollowMode.NEVER,
+                ignore_mode=monocdk.IgnoreMode.GLOB
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "source_path": source_path,
