@@ -1,14 +1,6 @@
 '''
 # AWS AutoScaling Common Library
 
-<!--BEGIN STABILITY BANNER-->---
-
-
-![cdk-constructs: Stable](https://img.shields.io/badge/cdk--constructs-stable-success.svg?style=for-the-badge)
-
----
-<!--END STABILITY BANNER-->
-
 This is a sister package to `@aws-cdk/aws-autoscaling` and
 `@aws-cdk/aws-applicationautoscaling`. It contains shared implementation
 details between them.
@@ -48,6 +40,18 @@ class Alarms:
         :param upper_alarm_interval_index: 
 
         :stability: experimental
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            from monocdk import aws_autoscaling_common as autoscaling_common
+            
+            alarms = autoscaling_common.Alarms(
+                lower_alarm_interval_index=123,
+                upper_alarm_interval_index=123
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if lower_alarm_interval_index is not None:
@@ -100,6 +104,24 @@ class ArbitraryIntervals:
         :param intervals: 
 
         :stability: experimental
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            from monocdk import aws_autoscaling_common as autoscaling_common
+            
+            arbitrary_intervals = autoscaling_common.ArbitraryIntervals(
+                absolute=False,
+                intervals=[autoscaling_common.ScalingInterval(
+                    change=123,
+            
+                    # the properties below are optional
+                    lower=123,
+                    upper=123
+                )]
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "absolute": absolute,
@@ -155,6 +177,21 @@ class CompleteScalingInterval:
         :param change: 
 
         :stability: experimental
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            from monocdk import aws_autoscaling_common as autoscaling_common
+            
+            complete_scaling_interval = autoscaling_common.CompleteScalingInterval(
+                lower=123,
+                upper=123,
+            
+                # the properties below are optional
+                change=123
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "lower": lower,
@@ -207,10 +244,6 @@ class IRandomGenerator(typing_extensions.Protocol):
     :stability: experimental
     '''
 
-    @builtins.staticmethod
-    def __jsii_proxy_class__() -> typing.Type["_IRandomGeneratorProxy"]:
-        return _IRandomGeneratorProxy
-
     @jsii.member(jsii_name="nextBoolean")
     def next_boolean(self) -> builtins.bool:
         '''
@@ -253,6 +286,9 @@ class _IRandomGeneratorProxy:
         '''
         return typing.cast(jsii.Number, jsii.invoke(self, "nextInt", [min, max]))
 
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, IRandomGenerator).__jsii_proxy_class__ = lambda : _IRandomGeneratorProxy
+
 
 @jsii.data_type(
     jsii_type="monocdk.aws_autoscaling_common.ScalingInterval",
@@ -274,6 +310,21 @@ class ScalingInterval:
         :param upper: (experimental) The upper bound of the interval. The scaling adjustment will be applied if the metric is lower than this value. Default: Threshold automatically derived from neighbouring intervals
 
         :stability: experimental
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            from monocdk import aws_autoscaling_common as autoscaling_common
+            
+            scaling_interval = autoscaling_common.ScalingInterval(
+                change=123,
+            
+                # the properties below are optional
+                lower=123,
+                upper=123
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "change": change,
