@@ -40,6 +40,7 @@ from ...aws_kms import IKey as _IKey_36930160
 from ...aws_lambda import (
     Alias as _Alias_9e39972c,
     AliasOptions as _AliasOptions_c9b06466,
+    Architecture as _Architecture_24056b62,
     Code as _Code_e8adcb06,
     EventInvokeConfigOptions as _EventInvokeConfigOptions_5cec26e1,
     EventSourceMapping as _EventSourceMapping_64d554a4,
@@ -53,6 +54,7 @@ from ...aws_lambda import (
     IFunction as _IFunction_6e14f09e,
     ILayerVersion as _ILayerVersion_b2b86380,
     IVersion as _IVersion_316c9051,
+    LambdaInsightsVersion as _LambdaInsightsVersion_2966e73b,
     LogRetentionRetryOptions as _LogRetentionRetryOptions_7acc40ab,
     Permission as _Permission_0b3dcf94,
     Runtime as _Runtime_932d369a,
@@ -63,6 +65,7 @@ from ...aws_lambda import (
     VersionWeight as _VersionWeight_7bcc86af,
 )
 from ...aws_logs import RetentionDays as _RetentionDays_6c560d31
+from ...aws_sns import ITopic as _ITopic_465e36b9
 from ...aws_sqs import IQueue as _IQueue_45a01ab4
 
 
@@ -81,7 +84,29 @@ class EdgeFunction(
     See https://docs.aws.amazon.com/cdk/latest/guide/bootstrapping.html or 'cdk bootstrap --help' for options.
 
     :stability: experimental
+    :exampleMetadata: infused
     :resource: AWS::Lambda::Function
+
+    Example::
+
+        # my_bucket: s3.Bucket
+        # A Lambda@Edge function added to default behavior of a Distribution
+        # and triggered on every request
+        my_func = cloudfront.experimental.EdgeFunction(self, "MyFunction",
+            runtime=lambda_.Runtime.NODEJS_12_X,
+            handler="index.handler",
+            code=lambda_.Code.from_asset(path.join(__dirname, "lambda-handler"))
+        )
+        cloudfront.Distribution(self, "myDist",
+            default_behavior=cloudfront.aws_cloudfront.BehaviorOptions(
+                origin=origins.S3Origin(my_bucket),
+                edge_lambdas=[cloudfront.aws_cloudfront.EdgeLambda(
+                    function_version=my_func.current_version,
+                    event_type=cloudfront.LambdaEdgeEventType.VIEWER_REQUEST
+                )
+                ]
+            )
+        )
     '''
 
     def __init__(
@@ -95,10 +120,13 @@ class EdgeFunction(
         runtime: _Runtime_932d369a,
         allow_all_outbound: typing.Optional[builtins.bool] = None,
         allow_public_subnet: typing.Optional[builtins.bool] = None,
+        architecture: typing.Optional[_Architecture_24056b62] = None,
+        architectures: typing.Optional[typing.Sequence[_Architecture_24056b62]] = None,
         code_signing_config: typing.Optional[_ICodeSigningConfig_5d77bccf] = None,
         current_version_options: typing.Optional[_VersionOptions_085bb455] = None,
         dead_letter_queue: typing.Optional[_IQueue_45a01ab4] = None,
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
+        dead_letter_topic: typing.Optional[_ITopic_465e36b9] = None,
         description: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         environment_encryption: typing.Optional[_IKey_36930160] = None,
@@ -106,6 +134,7 @@ class EdgeFunction(
         filesystem: typing.Optional[_FileSystem_17be1f4c] = None,
         function_name: typing.Optional[builtins.str] = None,
         initial_policy: typing.Optional[typing.Sequence[_PolicyStatement_296fe8a3]] = None,
+        insights_version: typing.Optional[_LambdaInsightsVersion_2966e73b] = None,
         layers: typing.Optional[typing.Sequence[_ILayerVersion_b2b86380]] = None,
         log_retention: typing.Optional[_RetentionDays_6c560d31] = None,
         log_retention_retry_options: typing.Optional[_LogRetentionRetryOptions_7acc40ab] = None,
@@ -135,10 +164,13 @@ class EdgeFunction(
         :param runtime: (experimental) The runtime environment for the Lambda function that you are uploading. For valid values, see the Runtime property in the AWS Lambda Developer Guide. Use ``Runtime.FROM_IMAGE`` when when defining a function from a Docker image.
         :param allow_all_outbound: (experimental) Whether to allow the Lambda to send all network traffic. If set to false, you must individually add traffic rules to allow the Lambda to connect to network targets. Default: true
         :param allow_public_subnet: (experimental) Lambda Functions in a public subnet can NOT access the internet. Use this property to acknowledge this limitation and still place the function in a public subnet. Default: false
+        :param architecture: (experimental) The system architectures compatible with this lambda function. Default: Architecture.X86_64
+        :param architectures: (deprecated) DEPRECATED. Default: [Architecture.X86_64]
         :param code_signing_config: (experimental) Code signing config associated with this function. Default: - Not Sign the Code
         :param current_version_options: (experimental) Options for the ``lambda.Version`` resource automatically created by the ``fn.currentVersion`` method. Default: - default options as described in ``VersionOptions``
-        :param dead_letter_queue: (experimental) The SQS queue to use if DLQ is enabled. Default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
+        :param dead_letter_queue: (experimental) The SQS queue to use if DLQ is enabled. If SNS topic is desired, specify ``deadLetterTopic`` property instead. Default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
         :param dead_letter_queue_enabled: (experimental) Enabled DLQ. If ``deadLetterQueue`` is undefined, an SQS queue with default options will be defined for your Function. Default: - false unless ``deadLetterQueue`` is set, which implies DLQ is enabled.
+        :param dead_letter_topic: (experimental) The SNS topic to use as a DLQ. Note that if ``deadLetterQueueEnabled`` is set to ``true``, an SQS queue will be created rather than an SNS topic. Using an SNS topic as a DLQ requires this property to be set explicitly. Default: - no SNS topic
         :param description: (experimental) A description of the function. Default: - No description.
         :param environment: (experimental) Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
         :param environment_encryption: (experimental) The AWS KMS key that's used to encrypt your function's environment variables. Default: - AWS Lambda creates and uses an AWS managed customer master key (CMK).
@@ -146,6 +178,7 @@ class EdgeFunction(
         :param filesystem: (experimental) The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: (experimental) A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
         :param initial_policy: (experimental) Initial policy statements to add to the created Lambda Role. You can call ``addToRolePolicy`` to the created lambda to add statements post creation. Default: - No policy statements are added to the created Lambda role.
+        :param insights_version: (experimental) Specify the version of CloudWatch Lambda insights to use for monitoring. Default: - No Lambda Insights
         :param layers: (experimental) A list of layers to add to the function's execution environment. You can configure your Lambda function to pull in additional code during initialization in the form of layers. Layers are packages of libraries or other dependencies that can be used by multiple functions. Default: - No layers.
         :param log_retention: (experimental) The number of days log events are kept in CloudWatch Logs. When updating this property, unsetting it doesn't remove the log retention policy. To remove the retention policy, set the value to ``INFINITE``. Default: logs.RetentionDays.INFINITE
         :param log_retention_retry_options: (experimental) When log retention is specified, a custom resource attempts to create the CloudWatch log group. These options control the retry policy when interacting with CloudWatch APIs. Default: - Default AWS SDK retry options.
@@ -175,10 +208,13 @@ class EdgeFunction(
             runtime=runtime,
             allow_all_outbound=allow_all_outbound,
             allow_public_subnet=allow_public_subnet,
+            architecture=architecture,
+            architectures=architectures,
             code_signing_config=code_signing_config,
             current_version_options=current_version_options,
             dead_letter_queue=dead_letter_queue,
             dead_letter_queue_enabled=dead_letter_queue_enabled,
+            dead_letter_topic=dead_letter_topic,
             description=description,
             environment=environment,
             environment_encryption=environment_encryption,
@@ -186,6 +222,7 @@ class EdgeFunction(
             filesystem=filesystem,
             function_name=function_name,
             initial_policy=initial_policy,
+            insights_version=insights_version,
             layers=layers,
             log_retention=log_retention,
             log_retention_retry_options=log_retention_retry_options,
@@ -207,7 +244,7 @@ class EdgeFunction(
             retry_attempts=retry_attempts,
         )
 
-        jsii.create(EdgeFunction, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="addAlias")
     def add_alias(
@@ -272,6 +309,7 @@ class EdgeFunction(
         max_record_age: typing.Optional[_Duration_070aa057] = None,
         on_failure: typing.Optional[_IEventSourceDlq_f5ae73e7] = None,
         parallelization_factor: typing.Optional[jsii.Number] = None,
+        report_batch_item_failures: typing.Optional[builtins.bool] = None,
         retry_attempts: typing.Optional[jsii.Number] = None,
         source_access_configurations: typing.Optional[typing.Sequence[_SourceAccessConfiguration_afc347bf]] = None,
         starting_position: typing.Optional[_StartingPosition_9192859a] = None,
@@ -280,7 +318,7 @@ class EdgeFunction(
         '''(experimental) Adds an event source that maps to this AWS Lambda function.
 
         :param id: -
-        :param batch_size: (experimental) The largest number of records that AWS Lambda will retrieve from your event source at the time of invoking your function. Your function receives an event with all the retrieved records. Valid Range: Minimum value of 1. Maximum value of 10000. Default: - Amazon Kinesis, Amazon DynamoDB, and Amazon MSK is 100 records. Both the default and maximum for Amazon SQS are 10 messages.
+        :param batch_size: (experimental) The largest number of records that AWS Lambda will retrieve from your event source at the time of invoking your function. Your function receives an event with all the retrieved records. Valid Range: Minimum value of 1. Maximum value of 10000. Default: - Amazon Kinesis, Amazon DynamoDB, and Amazon MSK is 100 records. The default for Amazon SQS is 10 messages. For standard SQS queues, the maximum is 10,000. For FIFO SQS queues, the maximum is 10.
         :param bisect_batch_on_error: (experimental) If the function returns an error, split the batch in two and retry. Default: false
         :param enabled: (experimental) Set to false to disable the event source upon creation. Default: true
         :param event_source_arn: (experimental) The Amazon Resource Name (ARN) of the event source. Any record added to this stream can invoke the Lambda function. Default: - not set if using a self managed Kafka cluster, throws an error otherwise
@@ -290,6 +328,7 @@ class EdgeFunction(
         :param max_record_age: (experimental) The maximum age of a record that Lambda sends to a function for processing. Valid Range: - Minimum value of 60 seconds - Maximum value of 7 days Default: - infinite or until the record expires.
         :param on_failure: (experimental) An Amazon SQS queue or Amazon SNS topic destination for discarded records. Default: discarded records are ignored
         :param parallelization_factor: (experimental) The number of batches to process from each shard concurrently. Valid Range: - Minimum value of 1 - Maximum value of 10 Default: 1
+        :param report_batch_item_failures: (experimental) Allow functions to return partially successful responses for a batch of records. Default: false
         :param retry_attempts: (experimental) The maximum number of times to retry when the function returns an error. Set to ``undefined`` if you want lambda to keep retrying infinitely or until the record expires. Valid Range: - Minimum value of 0 - Maximum value of 10000 Default: - infinite or until the record expires.
         :param source_access_configurations: (experimental) Specific settings like the authentication protocol or the VPC components to secure access to your event source. Default: - none
         :param starting_position: (experimental) The position in the DynamoDB, Kinesis or MSK stream where AWS Lambda should start reading. Default: - Required for Amazon Kinesis, Amazon DynamoDB, and Amazon MSK Streams sources.
@@ -308,6 +347,7 @@ class EdgeFunction(
             max_record_age=max_record_age,
             on_failure=on_failure,
             parallelization_factor=parallelization_factor,
+            report_batch_item_failures=report_batch_item_failures,
             retry_attempts=retry_attempts,
             source_access_configurations=source_access_configurations,
             starting_position=starting_position,
@@ -406,6 +446,7 @@ class EdgeFunction(
         account: typing.Optional[builtins.str] = None,
         color: typing.Optional[builtins.str] = None,
         dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         label: typing.Optional[builtins.str] = None,
         period: typing.Optional[_Duration_070aa057] = None,
         region: typing.Optional[builtins.str] = None,
@@ -417,7 +458,8 @@ class EdgeFunction(
         :param metric_name: -
         :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
         :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
-        :param dimensions: (experimental) Dimensions of the metric. Default: - No dimensions.
+        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
+        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
         :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
         :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
         :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
@@ -430,6 +472,7 @@ class EdgeFunction(
             account=account,
             color=color,
             dimensions=dimensions,
+            dimensions_map=dimensions_map,
             label=label,
             period=period,
             region=region,
@@ -446,6 +489,7 @@ class EdgeFunction(
         account: typing.Optional[builtins.str] = None,
         color: typing.Optional[builtins.str] = None,
         dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         label: typing.Optional[builtins.str] = None,
         period: typing.Optional[_Duration_070aa057] = None,
         region: typing.Optional[builtins.str] = None,
@@ -458,7 +502,8 @@ class EdgeFunction(
 
         :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
         :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
-        :param dimensions: (experimental) Dimensions of the metric. Default: - No dimensions.
+        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
+        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
         :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
         :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
         :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
@@ -471,6 +516,7 @@ class EdgeFunction(
             account=account,
             color=color,
             dimensions=dimensions,
+            dimensions_map=dimensions_map,
             label=label,
             period=period,
             region=region,
@@ -487,6 +533,7 @@ class EdgeFunction(
         account: typing.Optional[builtins.str] = None,
         color: typing.Optional[builtins.str] = None,
         dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         label: typing.Optional[builtins.str] = None,
         period: typing.Optional[_Duration_070aa057] = None,
         region: typing.Optional[builtins.str] = None,
@@ -499,7 +546,8 @@ class EdgeFunction(
 
         :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
         :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
-        :param dimensions: (experimental) Dimensions of the metric. Default: - No dimensions.
+        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
+        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
         :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
         :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
         :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
@@ -512,6 +560,7 @@ class EdgeFunction(
             account=account,
             color=color,
             dimensions=dimensions,
+            dimensions_map=dimensions_map,
             label=label,
             period=period,
             region=region,
@@ -528,6 +577,7 @@ class EdgeFunction(
         account: typing.Optional[builtins.str] = None,
         color: typing.Optional[builtins.str] = None,
         dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         label: typing.Optional[builtins.str] = None,
         period: typing.Optional[_Duration_070aa057] = None,
         region: typing.Optional[builtins.str] = None,
@@ -540,7 +590,8 @@ class EdgeFunction(
 
         :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
         :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
-        :param dimensions: (experimental) Dimensions of the metric. Default: - No dimensions.
+        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
+        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
         :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
         :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
         :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
@@ -553,6 +604,7 @@ class EdgeFunction(
             account=account,
             color=color,
             dimensions=dimensions,
+            dimensions_map=dimensions_map,
             label=label,
             period=period,
             region=region,
@@ -569,6 +621,7 @@ class EdgeFunction(
         account: typing.Optional[builtins.str] = None,
         color: typing.Optional[builtins.str] = None,
         dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         label: typing.Optional[builtins.str] = None,
         period: typing.Optional[_Duration_070aa057] = None,
         region: typing.Optional[builtins.str] = None,
@@ -581,7 +634,8 @@ class EdgeFunction(
 
         :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
         :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
-        :param dimensions: (experimental) Dimensions of the metric. Default: - No dimensions.
+        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
+        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
         :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
         :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
         :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
@@ -594,6 +648,7 @@ class EdgeFunction(
             account=account,
             color=color,
             dimensions=dimensions,
+            dimensions_map=dimensions_map,
             label=label,
             period=period,
             region=region,
@@ -603,6 +658,15 @@ class EdgeFunction(
 
         return typing.cast(_Metric_5b2b8e58, jsii.invoke(self, "metricThrottles", [props]))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="architecture")
+    def architecture(self) -> _Architecture_24056b62:
+        '''(experimental) The system architectures compatible with this lambda function.
+
+        :stability: experimental
+        '''
+        return typing.cast(_Architecture_24056b62, jsii.get(self, "architecture"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="connections")
     def connections(self) -> _Connections_57ccbda9:
@@ -635,7 +699,7 @@ class EdgeFunction(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="functionArn")
     def function_arn(self) -> builtins.str:
-        '''(experimental) The ARN fo the function.
+        '''(experimental) The ARN of the function.
 
         :stability: experimental
         '''
@@ -733,10 +797,13 @@ class EdgeFunction(
         "retry_attempts": "retryAttempts",
         "allow_all_outbound": "allowAllOutbound",
         "allow_public_subnet": "allowPublicSubnet",
+        "architecture": "architecture",
+        "architectures": "architectures",
         "code_signing_config": "codeSigningConfig",
         "current_version_options": "currentVersionOptions",
         "dead_letter_queue": "deadLetterQueue",
         "dead_letter_queue_enabled": "deadLetterQueueEnabled",
+        "dead_letter_topic": "deadLetterTopic",
         "description": "description",
         "environment": "environment",
         "environment_encryption": "environmentEncryption",
@@ -744,6 +811,7 @@ class EdgeFunction(
         "filesystem": "filesystem",
         "function_name": "functionName",
         "initial_policy": "initialPolicy",
+        "insights_version": "insightsVersion",
         "layers": "layers",
         "log_retention": "logRetention",
         "log_retention_retry_options": "logRetentionRetryOptions",
@@ -775,10 +843,13 @@ class EdgeFunctionProps(_FunctionProps_5561697c):
         retry_attempts: typing.Optional[jsii.Number] = None,
         allow_all_outbound: typing.Optional[builtins.bool] = None,
         allow_public_subnet: typing.Optional[builtins.bool] = None,
+        architecture: typing.Optional[_Architecture_24056b62] = None,
+        architectures: typing.Optional[typing.Sequence[_Architecture_24056b62]] = None,
         code_signing_config: typing.Optional[_ICodeSigningConfig_5d77bccf] = None,
         current_version_options: typing.Optional[_VersionOptions_085bb455] = None,
         dead_letter_queue: typing.Optional[_IQueue_45a01ab4] = None,
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
+        dead_letter_topic: typing.Optional[_ITopic_465e36b9] = None,
         description: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         environment_encryption: typing.Optional[_IKey_36930160] = None,
@@ -786,6 +857,7 @@ class EdgeFunctionProps(_FunctionProps_5561697c):
         filesystem: typing.Optional[_FileSystem_17be1f4c] = None,
         function_name: typing.Optional[builtins.str] = None,
         initial_policy: typing.Optional[typing.Sequence[_PolicyStatement_296fe8a3]] = None,
+        insights_version: typing.Optional[_LambdaInsightsVersion_2966e73b] = None,
         layers: typing.Optional[typing.Sequence[_ILayerVersion_b2b86380]] = None,
         log_retention: typing.Optional[_RetentionDays_6c560d31] = None,
         log_retention_retry_options: typing.Optional[_LogRetentionRetryOptions_7acc40ab] = None,
@@ -814,10 +886,13 @@ class EdgeFunctionProps(_FunctionProps_5561697c):
         :param retry_attempts: (experimental) The maximum number of times to retry when the function returns an error. Minimum: 0 Maximum: 2 Default: 2
         :param allow_all_outbound: (experimental) Whether to allow the Lambda to send all network traffic. If set to false, you must individually add traffic rules to allow the Lambda to connect to network targets. Default: true
         :param allow_public_subnet: (experimental) Lambda Functions in a public subnet can NOT access the internet. Use this property to acknowledge this limitation and still place the function in a public subnet. Default: false
+        :param architecture: (experimental) The system architectures compatible with this lambda function. Default: Architecture.X86_64
+        :param architectures: (deprecated) DEPRECATED. Default: [Architecture.X86_64]
         :param code_signing_config: (experimental) Code signing config associated with this function. Default: - Not Sign the Code
         :param current_version_options: (experimental) Options for the ``lambda.Version`` resource automatically created by the ``fn.currentVersion`` method. Default: - default options as described in ``VersionOptions``
-        :param dead_letter_queue: (experimental) The SQS queue to use if DLQ is enabled. Default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
+        :param dead_letter_queue: (experimental) The SQS queue to use if DLQ is enabled. If SNS topic is desired, specify ``deadLetterTopic`` property instead. Default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
         :param dead_letter_queue_enabled: (experimental) Enabled DLQ. If ``deadLetterQueue`` is undefined, an SQS queue with default options will be defined for your Function. Default: - false unless ``deadLetterQueue`` is set, which implies DLQ is enabled.
+        :param dead_letter_topic: (experimental) The SNS topic to use as a DLQ. Note that if ``deadLetterQueueEnabled`` is set to ``true``, an SQS queue will be created rather than an SNS topic. Using an SNS topic as a DLQ requires this property to be set explicitly. Default: - no SNS topic
         :param description: (experimental) A description of the function. Default: - No description.
         :param environment: (experimental) Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
         :param environment_encryption: (experimental) The AWS KMS key that's used to encrypt your function's environment variables. Default: - AWS Lambda creates and uses an AWS managed customer master key (CMK).
@@ -825,6 +900,7 @@ class EdgeFunctionProps(_FunctionProps_5561697c):
         :param filesystem: (experimental) The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: (experimental) A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
         :param initial_policy: (experimental) Initial policy statements to add to the created Lambda Role. You can call ``addToRolePolicy`` to the created lambda to add statements post creation. Default: - No policy statements are added to the created Lambda role.
+        :param insights_version: (experimental) Specify the version of CloudWatch Lambda insights to use for monitoring. Default: - No Lambda Insights
         :param layers: (experimental) A list of layers to add to the function's execution environment. You can configure your Lambda function to pull in additional code during initialization in the form of layers. Layers are packages of libraries or other dependencies that can be used by multiple functions. Default: - No layers.
         :param log_retention: (experimental) The number of days log events are kept in CloudWatch Logs. When updating this property, unsetting it doesn't remove the log retention policy. To remove the retention policy, set the value to ``INFINITE``. Default: logs.RetentionDays.INFINITE
         :param log_retention_retry_options: (experimental) When log retention is specified, a custom resource attempts to create the CloudWatch log group. These options control the retry policy when interacting with CloudWatch APIs. Default: - Default AWS SDK retry options.
@@ -846,6 +922,28 @@ class EdgeFunctionProps(_FunctionProps_5561697c):
         :param stack_id: (experimental) The stack ID of Lambda@Edge function. Default: - ``edge-lambda-stack-${region}``
 
         :stability: experimental
+        :exampleMetadata: infused
+
+        Example::
+
+            # my_bucket: s3.Bucket
+            # A Lambda@Edge function added to default behavior of a Distribution
+            # and triggered on every request
+            my_func = cloudfront.experimental.EdgeFunction(self, "MyFunction",
+                runtime=lambda_.Runtime.NODEJS_12_X,
+                handler="index.handler",
+                code=lambda_.Code.from_asset(path.join(__dirname, "lambda-handler"))
+            )
+            cloudfront.Distribution(self, "myDist",
+                default_behavior=cloudfront.aws_cloudfront.BehaviorOptions(
+                    origin=origins.S3Origin(my_bucket),
+                    edge_lambdas=[cloudfront.aws_cloudfront.EdgeLambda(
+                        function_version=my_func.current_version,
+                        event_type=cloudfront.LambdaEdgeEventType.VIEWER_REQUEST
+                    )
+                    ]
+                )
+            )
         '''
         if isinstance(current_version_options, dict):
             current_version_options = _VersionOptions_085bb455(**current_version_options)
@@ -870,6 +968,10 @@ class EdgeFunctionProps(_FunctionProps_5561697c):
             self._values["allow_all_outbound"] = allow_all_outbound
         if allow_public_subnet is not None:
             self._values["allow_public_subnet"] = allow_public_subnet
+        if architecture is not None:
+            self._values["architecture"] = architecture
+        if architectures is not None:
+            self._values["architectures"] = architectures
         if code_signing_config is not None:
             self._values["code_signing_config"] = code_signing_config
         if current_version_options is not None:
@@ -878,6 +980,8 @@ class EdgeFunctionProps(_FunctionProps_5561697c):
             self._values["dead_letter_queue"] = dead_letter_queue
         if dead_letter_queue_enabled is not None:
             self._values["dead_letter_queue_enabled"] = dead_letter_queue_enabled
+        if dead_letter_topic is not None:
+            self._values["dead_letter_topic"] = dead_letter_topic
         if description is not None:
             self._values["description"] = description
         if environment is not None:
@@ -892,6 +996,8 @@ class EdgeFunctionProps(_FunctionProps_5561697c):
             self._values["function_name"] = function_name
         if initial_policy is not None:
             self._values["initial_policy"] = initial_policy
+        if insights_version is not None:
+            self._values["insights_version"] = insights_version
         if layers is not None:
             self._values["layers"] = layers
         if log_retention is not None:
@@ -1003,6 +1109,30 @@ class EdgeFunctionProps(_FunctionProps_5561697c):
         result = self._values.get("allow_public_subnet")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def architecture(self) -> typing.Optional[_Architecture_24056b62]:
+        '''(experimental) The system architectures compatible with this lambda function.
+
+        :default: Architecture.X86_64
+
+        :stability: experimental
+        '''
+        result = self._values.get("architecture")
+        return typing.cast(typing.Optional[_Architecture_24056b62], result)
+
+    @builtins.property
+    def architectures(self) -> typing.Optional[typing.List[_Architecture_24056b62]]:
+        '''(deprecated) DEPRECATED.
+
+        :default: [Architecture.X86_64]
+
+        :deprecated: use ``architecture``
+
+        :stability: deprecated
+        '''
+        result = self._values.get("architectures")
+        return typing.cast(typing.Optional[typing.List[_Architecture_24056b62]], result)
+
     @builtins.property
     def code_signing_config(self) -> typing.Optional[_ICodeSigningConfig_5d77bccf]:
         '''(experimental) Code signing config associated with this function.
@@ -1029,6 +1159,8 @@ class EdgeFunctionProps(_FunctionProps_5561697c):
     def dead_letter_queue(self) -> typing.Optional[_IQueue_45a01ab4]:
         '''(experimental) The SQS queue to use if DLQ is enabled.
 
+        If SNS topic is desired, specify ``deadLetterTopic`` property instead.
+
         :default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
 
         :stability: experimental
@@ -1050,6 +1182,20 @@ class EdgeFunctionProps(_FunctionProps_5561697c):
         result = self._values.get("dead_letter_queue_enabled")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def dead_letter_topic(self) -> typing.Optional[_ITopic_465e36b9]:
+        '''(experimental) The SNS topic to use as a DLQ.
+
+        Note that if ``deadLetterQueueEnabled`` is set to ``true``, an SQS queue will be created
+        rather than an SNS topic. Using an SNS topic as a DLQ requires this property to be set explicitly.
+
+        :default: - no SNS topic
+
+        :stability: experimental
+        '''
+        result = self._values.get("dead_letter_topic")
+        return typing.cast(typing.Optional[_ITopic_465e36b9], result)
+
     @builtins.property
     def description(self) -> typing.Optional[builtins.str]:
         '''(experimental) A description of the function.
@@ -1140,6 +1286,18 @@ class EdgeFunctionProps(_FunctionProps_5561697c):
         result = self._values.get("initial_policy")
         return typing.cast(typing.Optional[typing.List[_PolicyStatement_296fe8a3]], result)
 
+    @builtins.property
+    def insights_version(self) -> typing.Optional[_LambdaInsightsVersion_2966e73b]:
+        '''(experimental) Specify the version of CloudWatch Lambda insights to use for monitoring.
+
+        :default: - No Lambda Insights
+
+        :see: https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Lambda-Insights-Getting-Started-docker.html
+        :stability: experimental
+        '''
+        result = self._values.get("insights_version")
+        return typing.cast(typing.Optional[_LambdaInsightsVersion_2966e73b], result)
+
     @builtins.property
     def layers(self) -> typing.Optional[typing.List[_ILayerVersion_b2b86380]]:
         '''(experimental) A list of layers to add to the function's execution environment.
