@@ -1,14 +1,6 @@
 '''
 # Targets for AWS Elastic Load Balancing V2
 
-<!--BEGIN STABILITY BANNER-->---
-
-
-![cdk-constructs: Stable](https://img.shields.io/badge/cdk--constructs-stable-success.svg?style=for-the-badge)
-
----
-<!--END STABILITY BANNER-->
-
 This package contains targets for ELBv2. See the README of the `@aws-cdk/aws-elasticloadbalancingv2` library.
 '''
 import abc
@@ -25,6 +17,7 @@ from .._jsii import *
 
 from ..aws_ec2 import Instance as _Instance_d6f39d19
 from ..aws_elasticloadbalancingv2 import (
+    ApplicationLoadBalancer as _ApplicationLoadBalancer_16524503,
     IApplicationLoadBalancerTarget as _IApplicationLoadBalancerTarget_db0fdc70,
     IApplicationTargetGroup as _IApplicationTargetGroup_5a474b2b,
     INetworkLoadBalancerTarget as _INetworkLoadBalancerTarget_6691f661,
@@ -34,6 +27,113 @@ from ..aws_elasticloadbalancingv2 import (
 from ..aws_lambda import IFunction as _IFunction_6e14f09e
 
 
+@jsii.implements(_INetworkLoadBalancerTarget_6691f661)
+class AlbArnTarget(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk.aws_elasticloadbalancingv2_targets.AlbArnTarget",
+):
+    '''(experimental) A single Application Load Balancer as the target for load balancing.
+
+    :stability: experimental
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        from monocdk import aws_elasticloadbalancingv2_targets as elasticloadbalancingv2_targets
+        
+        alb_arn_target = elasticloadbalancingv2_targets.AlbArnTarget("albArn", 123)
+    '''
+
+    def __init__(self, alb_arn: builtins.str, port: jsii.Number) -> None:
+        '''(experimental) Create a new alb target.
+
+        :param alb_arn: The ARN of the application load balancer to load balance to.
+        :param port: The port on which the target is listening.
+
+        :stability: experimental
+        '''
+        jsii.create(self.__class__, self, [alb_arn, port])
+
+    @jsii.member(jsii_name="attachToNetworkTargetGroup")
+    def attach_to_network_target_group(
+        self,
+        target_group: _INetworkTargetGroup_6938b578,
+    ) -> _LoadBalancerTargetProps_8b99f223:
+        '''(experimental) Register this alb target with a load balancer.
+
+        Don't call this, it is called automatically when you add the target to a
+        load balancer.
+
+        :param target_group: -
+
+        :stability: experimental
+        '''
+        return typing.cast(_LoadBalancerTargetProps_8b99f223, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
+
+
+class AlbTarget(
+    AlbArnTarget,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk.aws_elasticloadbalancingv2_targets.AlbTarget",
+):
+    '''(experimental) A single Application Load Balancer as the target for load balancing.
+
+    :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        import monocdk as targets
+        import monocdk as ecs
+        import monocdk as patterns
+        
+        # vpc: ec2.Vpc
+        
+        
+        task = ecs.FargateTaskDefinition(self, "Task", cpu=256, memory_limit_mi_b=512)
+        task.add_container("nginx",
+            image=ecs.ContainerImage.from_registry("public.ecr.aws/nginx/nginx:latest"),
+            port_mappings=[targets.aws_ecs.PortMapping(container_port=80)]
+        )
+        
+        svc = patterns.ApplicationLoadBalancedFargateService(self, "Service",
+            vpc=vpc,
+            task_definition=task,
+            public_load_balancer=False
+        )
+        
+        nlb = elbv2.NetworkLoadBalancer(self, "Nlb",
+            vpc=vpc,
+            cross_zone_enabled=True,
+            internet_facing=True
+        )
+        
+        listener = nlb.add_listener("listener", port=80)
+        
+        listener.add_targets("Targets",
+            targets=[targets.AlbTarget(svc.load_balancer, 80)],
+            port=80
+        )
+        
+        CfnOutput(self, "NlbEndpoint", value=f"http://{nlb.loadBalancerDnsName}")
+    '''
+
+    def __init__(
+        self,
+        alb: _ApplicationLoadBalancer_16524503,
+        port: jsii.Number,
+    ) -> None:
+        '''
+        :param alb: The application load balancer to load balance to.
+        :param port: The port on which the target is listening.
+
+        :stability: experimental
+        '''
+        jsii.create(self.__class__, self, [alb, port])
+
+
 @jsii.implements(_IApplicationLoadBalancerTarget_db0fdc70, _INetworkLoadBalancerTarget_6691f661)
 class InstanceIdTarget(
     metaclass=jsii.JSIIMeta,
@@ -45,6 +145,15 @@ class InstanceIdTarget(
     sure the load balancer's security group can connect to the instance.
 
     :stability: experimental
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        from monocdk import aws_elasticloadbalancingv2_targets as elasticloadbalancingv2_targets
+        
+        instance_id_target = elasticloadbalancingv2_targets.InstanceIdTarget("instanceId", 123)
     '''
 
     def __init__(
@@ -59,7 +168,7 @@ class InstanceIdTarget(
 
         :stability: experimental
         '''
-        jsii.create(InstanceIdTarget, self, [instance_id, port])
+        jsii.create(self.__class__, self, [instance_id, port])
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
     def attach_to_application_target_group(
@@ -101,6 +210,18 @@ class InstanceTarget(
 ):
     '''
     :stability: experimental
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        from monocdk import aws_ec2 as ec2
+        from monocdk import aws_elasticloadbalancingv2_targets as elasticloadbalancingv2_targets
+        
+        # instance: ec2.Instance
+        
+        instance_target = elasticloadbalancingv2_targets.InstanceTarget(instance, 123)
     '''
 
     def __init__(
@@ -115,7 +236,7 @@ class InstanceTarget(
 
         :stability: experimental
         '''
-        jsii.create(InstanceTarget, self, [instance, port])
+        jsii.create(self.__class__, self, [instance, port])
 
 
 @jsii.implements(_IApplicationLoadBalancerTarget_db0fdc70, _INetworkLoadBalancerTarget_6691f661)
@@ -134,6 +255,15 @@ class IpTarget(
     sure the load balancer's security group can send packets to the IP address.
 
     :stability: experimental
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        from monocdk import aws_elasticloadbalancingv2_targets as elasticloadbalancingv2_targets
+        
+        ip_target = elasticloadbalancingv2_targets.IpTarget("ipAddress", 123, "availabilityZone")
     '''
 
     def __init__(
@@ -165,7 +295,7 @@ class IpTarget(
 
         :stability: experimental
         '''
-        jsii.create(IpTarget, self, [ip_address, port, availability_zone])
+        jsii.create(self.__class__, self, [ip_address, port, availability_zone])
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
     def attach_to_application_target_group(
@@ -207,6 +337,27 @@ class LambdaTarget(
 ):
     '''
     :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        import monocdk as lambda_
+        import monocdk as targets
+        
+        # lambda_function: lambda.Function
+        # lb: elbv2.ApplicationLoadBalancer
+        
+        
+        listener = lb.add_listener("Listener", port=80)
+        listener.add_targets("Targets",
+            targets=[targets.LambdaTarget(lambda_function)],
+        
+            # For Lambda Targets, you need to explicitly enable health checks if you
+            # want them.
+            health_check=lambda.aws_elasticloadbalancingv2.HealthCheck(
+                enabled=True
+            )
+        )
     '''
 
     def __init__(self, fn: _IFunction_6e14f09e) -> None:
@@ -216,7 +367,7 @@ class LambdaTarget(
 
         :stability: experimental
         '''
-        jsii.create(LambdaTarget, self, [fn])
+        jsii.create(self.__class__, self, [fn])
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
     def attach_to_application_target_group(
@@ -252,6 +403,8 @@ class LambdaTarget(
 
 
 __all__ = [
+    "AlbArnTarget",
+    "AlbTarget",
     "InstanceIdTarget",
     "InstanceTarget",
     "IpTarget",
