@@ -1,14 +1,6 @@
 '''
 # Endpoints for AWS Global Accelerator
 
-<!--BEGIN STABILITY BANNER-->---
-
-
-![cdk-constructs: Stable](https://img.shields.io/badge/cdk--constructs-stable-success.svg?style=for-the-badge)
-
----
-<!--END STABILITY BANNER-->
-
 This library contains integration classes to reference endpoints in AWS
 Global Accelerator. Instances of these classes should be passed to the
 `endpointGroup.addEndpoint()` method.
@@ -45,6 +37,22 @@ class ApplicationLoadBalancerEndpoint(
     '''(experimental) Use an Application Load Balancer as a Global Accelerator Endpoint.
 
     :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        # alb: elbv2.ApplicationLoadBalancer
+        # listener: globalaccelerator.Listener
+        
+        
+        listener.add_endpoint_group("Group",
+            endpoints=[
+                ga_endpoints.ApplicationLoadBalancerEndpoint(alb,
+                    weight=128,
+                    preserve_client_ip=True
+                )
+            ]
+        )
     '''
 
     def __init__(
@@ -65,7 +73,7 @@ class ApplicationLoadBalancerEndpoint(
             preserve_client_ip=preserve_client_ip, weight=weight
         )
 
-        jsii.create(ApplicationLoadBalancerEndpoint, self, [load_balancer, options])
+        jsii.create(self.__class__, self, [load_balancer, options])
 
     @jsii.member(jsii_name="renderEndpointConfiguration")
     def render_endpoint_configuration(self) -> typing.Any:
@@ -105,6 +113,22 @@ class ApplicationLoadBalancerEndpointOptions:
         :param weight: (experimental) Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
 
         :stability: experimental
+        :exampleMetadata: infused
+
+        Example::
+
+            # alb: elbv2.ApplicationLoadBalancer
+            # listener: globalaccelerator.Listener
+            
+            
+            listener.add_endpoint_group("Group",
+                endpoints=[
+                    ga_endpoints.ApplicationLoadBalancerEndpoint(alb,
+                        weight=128,
+                        preserve_client_ip=True
+                    )
+                ]
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if preserve_client_ip is not None:
@@ -162,6 +186,21 @@ class CfnEipEndpoint(
     '''(experimental) Use an EC2 Instance as a Global Accelerator Endpoint.
 
     :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        # listener: globalaccelerator.Listener
+        # eip: ec2.CfnEIP
+        
+        
+        listener.add_endpoint_group("Group",
+            endpoints=[
+                ga_endpoints.CfnEipEndpoint(eip,
+                    weight=128
+                )
+            ]
+        )
     '''
 
     def __init__(
@@ -178,7 +217,7 @@ class CfnEipEndpoint(
         '''
         options = CfnEipEndpointProps(weight=weight)
 
-        jsii.create(CfnEipEndpoint, self, [eip, options])
+        jsii.create(self.__class__, self, [eip, options])
 
     @jsii.member(jsii_name="renderEndpointConfiguration")
     def render_endpoint_configuration(self) -> typing.Any:
@@ -212,6 +251,21 @@ class CfnEipEndpointProps:
         :param weight: (experimental) Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
 
         :stability: experimental
+        :exampleMetadata: infused
+
+        Example::
+
+            # listener: globalaccelerator.Listener
+            # eip: ec2.CfnEIP
+            
+            
+            listener.add_endpoint_group("Group",
+                endpoints=[
+                    ga_endpoints.CfnEipEndpoint(eip,
+                        weight=128
+                    )
+                ]
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if weight is not None:
@@ -250,6 +304,22 @@ class InstanceEndpoint(
     '''(experimental) Use an EC2 Instance as a Global Accelerator Endpoint.
 
     :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        # listener: globalaccelerator.Listener
+        # instance: ec2.Instance
+        
+        
+        listener.add_endpoint_group("Group",
+            endpoints=[
+                ga_endpoints.InstanceEndpoint(instance,
+                    weight=128,
+                    preserve_client_ip=True
+                )
+            ]
+        )
     '''
 
     def __init__(
@@ -270,7 +340,7 @@ class InstanceEndpoint(
             preserve_client_ip=preserve_client_ip, weight=weight
         )
 
-        jsii.create(InstanceEndpoint, self, [instance, options])
+        jsii.create(self.__class__, self, [instance, options])
 
     @jsii.member(jsii_name="renderEndpointConfiguration")
     def render_endpoint_configuration(self) -> typing.Any:
@@ -310,6 +380,22 @@ class InstanceEndpointProps:
         :param weight: (experimental) Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
 
         :stability: experimental
+        :exampleMetadata: infused
+
+        Example::
+
+            # listener: globalaccelerator.Listener
+            # instance: ec2.Instance
+            
+            
+            listener.add_endpoint_group("Group",
+                endpoints=[
+                    ga_endpoints.InstanceEndpoint(instance,
+                        weight=128,
+                        preserve_client_ip=True
+                    )
+                ]
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if preserve_client_ip is not None:
@@ -367,6 +453,37 @@ class NetworkLoadBalancerEndpoint(
     '''(experimental) Use a Network Load Balancer as a Global Accelerator Endpoint.
 
     :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        # Create an Accelerator
+        accelerator = globalaccelerator.Accelerator(self, "Accelerator")
+        
+        # Create a Listener
+        listener = accelerator.add_listener("Listener",
+            port_ranges=[globalaccelerator.aws_globalaccelerator.PortRange(from_port=80), globalaccelerator.aws_globalaccelerator.PortRange(from_port=443)
+            ]
+        )
+        
+        # Import the Load Balancers
+        nlb1 = elbv2.NetworkLoadBalancer.from_network_load_balancer_attributes(self, "NLB1",
+            load_balancer_arn="arn:aws:elasticloadbalancing:us-west-2:111111111111:loadbalancer/app/my-load-balancer1/e16bef66805b"
+        )
+        nlb2 = elbv2.NetworkLoadBalancer.from_network_load_balancer_attributes(self, "NLB2",
+            load_balancer_arn="arn:aws:elasticloadbalancing:ap-south-1:111111111111:loadbalancer/app/my-load-balancer2/5513dc2ea8a1"
+        )
+        
+        # Add one EndpointGroup for each Region we are targeting
+        listener.add_endpoint_group("Group1",
+            endpoints=[ga_endpoints.NetworkLoadBalancerEndpoint(nlb1)]
+        )
+        listener.add_endpoint_group("Group2",
+            # Imported load balancers automatically calculate their Region from the ARN.
+            # If you are load balancing to other resources, you must also pass a `region`
+            # parameter here.
+            endpoints=[ga_endpoints.NetworkLoadBalancerEndpoint(nlb2)]
+        )
     '''
 
     def __init__(
@@ -383,7 +500,7 @@ class NetworkLoadBalancerEndpoint(
         '''
         options = NetworkLoadBalancerEndpointProps(weight=weight)
 
-        jsii.create(NetworkLoadBalancerEndpoint, self, [load_balancer, options])
+        jsii.create(self.__class__, self, [load_balancer, options])
 
     @jsii.member(jsii_name="renderEndpointConfiguration")
     def render_endpoint_configuration(self) -> typing.Any:
@@ -417,6 +534,21 @@ class NetworkLoadBalancerEndpointProps:
         :param weight: (experimental) Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
 
         :stability: experimental
+        :exampleMetadata: infused
+
+        Example::
+
+            # nlb: elbv2.NetworkLoadBalancer
+            # listener: globalaccelerator.Listener
+            
+            
+            listener.add_endpoint_group("Group",
+                endpoints=[
+                    ga_endpoints.NetworkLoadBalancerEndpoint(nlb,
+                        weight=128
+                    )
+                ]
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if weight is not None:
