@@ -1,14 +1,6 @@
 '''
 # AWS CDK Assets
 
-<!--BEGIN STABILITY BANNER-->---
-
-
-![cdk-constructs: Stable](https://img.shields.io/badge/cdk--constructs-stable-success.svg?style=for-the-badge)
-
----
-<!--END STABILITY BANNER-->
-
 Assets are local files or directories which are needed by a CDK app. A common
 example is a directory which contains the handler code for a Lambda function,
 but assets can represent any artifact that is needed for the app's operation.
@@ -21,12 +13,20 @@ to the relevant stacks.
 The following JavaScript example defines an directory asset which is archived as
 a .zip file and uploaded to S3 during deployment.
 
-[Example of a ZipDirectoryAsset](./test/integ.assets.directory.lit.ts)
+```python
+asset = assets.Asset(self, "SampleAsset",
+    path=path.join(__dirname, "sample-asset-directory")
+)
+```
 
 The following JavaScript example defines a file asset, which is uploaded as-is
 to an S3 bucket during deployment.
 
-[Example of a FileAsset](./test/integ.assets.file.lit.ts)
+```python
+asset = assets.Asset(self, "SampleAsset",
+    path=path.join(__dirname, "file-asset.txt")
+)
+```
 
 ## Attributes
 
@@ -39,7 +39,16 @@ to an S3 bucket during deployment.
 
 In the following example, the various asset attributes are exported as stack outputs:
 
-[Example of referencing an asset](./test/integ.assets.refs.lit.ts)
+```python
+asset = assets.Asset(self, "SampleAsset",
+    path=path.join(__dirname, "sample-asset-directory")
+)
+
+cdk.CfnOutput(self, "S3BucketName", value=asset.s3_bucket_name)
+cdk.CfnOutput(self, "S3ObjectKey", value=asset.s3_object_key)
+cdk.CfnOutput(self, "S3HttpURL", value=asset.http_url)
+cdk.CfnOutput(self, "S3ObjectURL", value=asset.s3_object_url)
+```
 
 ## Permissions
 
@@ -48,7 +57,10 @@ granted IAM permissions. To do that use the `asset.grantRead(principal)` method:
 
 The following examples grants an IAM group read permissions on an asset:
 
-[Example of granting read access to an asset](./test/integ.assets.permissions.lit.ts)
+```python
+group = iam.Group(self, "MyUserGroup")
+asset.grant_read(group)
+```
 
 ## How does it work
 
@@ -80,7 +92,18 @@ be zipped and uploaded to S3 as the asset.
 
 The following example uses custom asset bundling to convert a markdown file to html:
 
-[Example of using asset bundling](./test/integ.assets.bundling.lit.ts).
+```python
+asset = assets.Asset(self, "BundledAsset",
+    path=path.join(__dirname, "markdown-asset"),  # /asset-input and working directory in the container
+    bundling=assets.BundlingOptions(
+        image=DockerImage.from_build(path.join(__dirname, "alpine-markdown")),  # Build an image
+        command=["sh", "-c", """
+                        markdown index.md > /asset-output/index.html
+                      """
+        ]
+    )
+)
+```
 
 The bundling docker image (`image`) can either come from a registry (`DockerImage.fromRegistry`)
 or it can be built from a `Dockerfile` located inside your project (`DockerImage.fromBuild`).
@@ -95,19 +118,24 @@ method `tryBundle()` which should return `true` if local bundling was performed.
 If `false` is returned, docker bundling will be done:
 
 ```python
-# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
+@jsii.implements(ILocalBundling)
+class MyBundle:
+    def try_bundle(self, output_dir, *, image, entrypoint=None, command=None, volumes=None, environment=None, workingDirectory=None, user=None, local=None, outputType=None, securityOpt=None):
+        can_run_locally = True # replace with actual logic
+        if can_run_locally:
+            # perform local bundling here
+            return True
+        return False
+
 assets.Asset(self, "BundledAsset",
     path="/path/to/asset",
-    bundling={
-        "local": {
-            def try_bundle(self, output_dir, options):
-                if can_run_locally: return Truereturn False
-        },
+    bundling=assets.BundlingOptions(
+        local=MyBundle(),
         # Docker bundling fallback
-        "image": DockerImage.from_registry("alpine"),
-        "entrypoint": ["/bin/sh", "-c"],
-        "command": ["bundle"]
-    }
+        image=DockerImage.from_registry("alpine"),
+        entrypoint=["/bin/sh", "-c"],
+        command=["bundle"]
+    )
 )
 ```
 
@@ -122,14 +150,13 @@ is the default behavior for `bundling.outputType` (`BundlingOutput.AUTO_DISCOVER
 Use `BundlingOutput.NOT_ARCHIVED` if the bundling output must always be zipped:
 
 ```python
-# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
 asset = assets.Asset(self, "BundledAsset",
     path="/path/to/asset",
-    bundling={
-        "image": DockerImage.from_registry("alpine"),
-        "command": ["command-that-produces-an-archive.sh"],
-        "output_type": BundlingOutput.NOT_ARCHIVED
-    }
+    bundling=assets.BundlingOptions(
+        image=DockerImage.from_registry("alpine"),
+        command=["command-that-produces-an-archive.sh"],
+        output_type=BundlingOutput.NOT_ARCHIVED
+    )
 )
 ```
 
@@ -198,6 +225,21 @@ class Asset(
     '''(experimental) An asset represents a local file or directory, which is automatically uploaded to S3 and then can be referenced within a CDK application.
 
     :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        import monocdk as s3_assets
+        
+        # cluster: eks.Cluster
+        
+        chart_asset = s3_assets.Asset(self, "ChartAsset",
+            path="/path/to/asset"
+        )
+        
+        cluster.add_helm_chart("test-chart",
+            chart_asset=chart_asset
+        )
     '''
 
     def __init__(
@@ -228,7 +270,7 @@ class Asset(
         :param follow_symlinks: (experimental) A strategy for how to handle symlinks. Default: SymlinkFollowMode.NEVER
         :param asset_hash: (experimental) Specify a custom hash for this asset. If ``assetHashType`` is set it must be set to ``AssetHashType.CUSTOM``. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the hash, you will need to make sure it is updated every time the asset changes, or otherwise it is possible that some deployments will not be invalidated. Default: - based on ``assetHashType``
         :param asset_hash_type: (experimental) Specifies the type of hash to calculate for this asset. If ``assetHash`` is configured, this option must be ``undefined`` or ``AssetHashType.CUSTOM``. Default: - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
-        :param bundling: (experimental) Bundle the asset by executing a command in a Docker container. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
+        :param bundling: (experimental) Bundle the asset by executing a command in a Docker container or a custom bundling provider. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
 
         :stability: experimental
         '''
@@ -245,7 +287,7 @@ class Asset(
             bundling=bundling,
         )
 
-        jsii.create(Asset, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="addResourceMetadata")
     def add_resource_metadata(
@@ -319,12 +361,9 @@ class Asset(
     def http_url(self) -> builtins.str:
         '''(experimental) Attribute which represents the S3 HTTP URL of this asset.
 
+        For example, ``https://s3.us-west-1.amazonaws.com/bucket/key``
+
         :stability: experimental
-
-        Example::
-
-            # Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
-            https:
         '''
         return typing.cast(builtins.str, jsii.get(self, "httpUrl"))
 
@@ -375,12 +414,9 @@ class Asset(
     def s3_object_url(self) -> builtins.str:
         '''(experimental) Attribute which represents the S3 URL of this asset.
 
+        For example, ``s3://bucket/key``
+
         :stability: experimental
-
-        Example::
-
-            # Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
-            s3:
         '''
         return typing.cast(builtins.str, jsii.get(self, "s3ObjectUrl"))
 
@@ -449,11 +485,26 @@ class AssetOptions(
         :param follow_symlinks: (experimental) A strategy for how to handle symlinks. Default: SymlinkFollowMode.NEVER
         :param asset_hash: (experimental) Specify a custom hash for this asset. If ``assetHashType`` is set it must be set to ``AssetHashType.CUSTOM``. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the hash, you will need to make sure it is updated every time the asset changes, or otherwise it is possible that some deployments will not be invalidated. Default: - based on ``assetHashType``
         :param asset_hash_type: (experimental) Specifies the type of hash to calculate for this asset. If ``assetHash`` is configured, this option must be ``undefined`` or ``AssetHashType.CUSTOM``. Default: - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
-        :param bundling: (experimental) Bundle the asset by executing a command in a Docker container. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
+        :param bundling: (experimental) Bundle the asset by executing a command in a Docker container or a custom bundling provider. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
         :param readers: (experimental) A list of principals that should be able to read this asset from S3. You can use ``asset.grantRead(principal)`` to grant read permissions later. Default: - No principals that can read file asset.
         :param source_hash: (deprecated) Custom hash to use when identifying the specific version of the asset. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the source hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the source hash, you will need to make sure it is updated every time the source changes, or otherwise it is possible that some deployments will not be invalidated. Default: - automatically calculate source hash based on the contents of the source file or directory.
 
         :stability: experimental
+        :exampleMetadata: infused
+
+        Example::
+
+            lambda_.Function(self, "Function",
+                code=lambda_.Code.from_asset(path.join(__dirname, "my-python-handler"),
+                    bundling=lambda.BundlingOptions(
+                        image=lambda_.Runtime.PYTHON_3_9.bundling_image,
+                        command=["bash", "-c", "pip install -r requirements.txt -t /asset-output && cp -au . /asset-output"
+                        ]
+                    )
+                ),
+                runtime=lambda_.Runtime.PYTHON_3_9,
+                handler="index.handler"
+            )
         '''
         if isinstance(bundling, dict):
             bundling = _BundlingOptions_ab115a99(**bundling)
@@ -564,7 +615,7 @@ class AssetOptions(
 
     @builtins.property
     def bundling(self) -> typing.Optional[_BundlingOptions_ab115a99]:
-        '''(experimental) Bundle the asset by executing a command in a Docker container.
+        '''(experimental) Bundle the asset by executing a command in a Docker container or a custom bundling provider.
 
         The asset path will be mounted at ``/asset-input``. The Docker
         container is responsible for putting content at ``/asset-output``.
@@ -670,12 +721,26 @@ class AssetProps(AssetOptions):
         :param follow_symlinks: (experimental) A strategy for how to handle symlinks. Default: SymlinkFollowMode.NEVER
         :param asset_hash: (experimental) Specify a custom hash for this asset. If ``assetHashType`` is set it must be set to ``AssetHashType.CUSTOM``. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the hash, you will need to make sure it is updated every time the asset changes, or otherwise it is possible that some deployments will not be invalidated. Default: - based on ``assetHashType``
         :param asset_hash_type: (experimental) Specifies the type of hash to calculate for this asset. If ``assetHash`` is configured, this option must be ``undefined`` or ``AssetHashType.CUSTOM``. Default: - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
-        :param bundling: (experimental) Bundle the asset by executing a command in a Docker container. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
+        :param bundling: (experimental) Bundle the asset by executing a command in a Docker container or a custom bundling provider. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
         :param readers: (experimental) A list of principals that should be able to read this asset from S3. You can use ``asset.grantRead(principal)`` to grant read permissions later. Default: - No principals that can read file asset.
         :param source_hash: (deprecated) Custom hash to use when identifying the specific version of the asset. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the source hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the source hash, you will need to make sure it is updated every time the source changes, or otherwise it is possible that some deployments will not be invalidated. Default: - automatically calculate source hash based on the contents of the source file or directory.
         :param path: (experimental) The disk location of the asset. The path should refer to one of the following: - A regular file or a .zip file, in which case the file will be uploaded as-is to S3. - A directory, in which case it will be archived into a .zip file and uploaded to S3.
 
         :stability: experimental
+        :exampleMetadata: lit=lib/aws-s3-assets/test/integ.assets.bundling.lit.ts infused
+
+        Example::
+
+            asset = assets.Asset(self, "BundledAsset",
+                path=path.join(__dirname, "markdown-asset"),  # /asset-input and working directory in the container
+                bundling=assets.BundlingOptions(
+                    image=DockerImage.from_build(path.join(__dirname, "alpine-markdown")),  # Build an image
+                    command=["sh", "-c", """
+                                    markdown index.md > /asset-output/index.html
+                                  """
+                    ]
+                )
+            )
         '''
         if isinstance(bundling, dict):
             bundling = _BundlingOptions_ab115a99(**bundling)
@@ -788,7 +853,7 @@ class AssetProps(AssetOptions):
 
     @builtins.property
     def bundling(self) -> typing.Optional[_BundlingOptions_ab115a99]:
-        '''(experimental) Bundle the asset by executing a command in a Docker container.
+        '''(experimental) Bundle the asset by executing a command in a Docker container or a custom bundling provider.
 
         The asset path will be mounted at ``/asset-input``. The Docker
         container is responsible for putting content at ``/asset-output``.
