@@ -1,14 +1,6 @@
 '''
 # Amazon Simple Email Service Actions Library
 
-<!--BEGIN STABILITY BANNER-->---
-
-
-![cdk-constructs: Stable](https://img.shields.io/badge/cdk--constructs-stable-success.svg?style=for-the-badge)
-
----
-<!--END STABILITY BANNER-->
-
 This module contains integration classes to add action to SES email receiving rules.
 Instances of these classes should be passed to the `rule.addAction()` method.
 
@@ -51,6 +43,41 @@ class AddHeader(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_ses_actions.AddH
     '''(experimental) Adds a header to the received email.
 
     :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        import monocdk as s3
+        import monocdk as actions
+        
+        
+        bucket = s3.Bucket(self, "Bucket")
+        topic = sns.Topic(self, "Topic")
+        
+        ses.ReceiptRuleSet(self, "RuleSet",
+            rules=[s3.aws_ses.ReceiptRuleOptions(
+                recipients=["hello@aws.com"],
+                actions=[
+                    actions.AddHeader(
+                        name="X-Special-Header",
+                        value="aws"
+                    ),
+                    actions.S3(
+                        bucket=bucket,
+                        object_key_prefix="emails/",
+                        topic=topic
+                    )
+                ]
+            ), s3.aws_ses.ReceiptRuleOptions(
+                recipients=["aws.com"],
+                actions=[
+                    actions.Sns(
+                        topic=topic
+                    )
+                ]
+            )
+            ]
+        )
     '''
 
     def __init__(self, *, name: builtins.str, value: builtins.str) -> None:
@@ -62,7 +89,7 @@ class AddHeader(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_ses_actions.AddH
         '''
         props = AddHeaderProps(name=name, value=value)
 
-        jsii.create(AddHeader, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="bind")
     def bind(self, _rule: _IReceiptRule_77e30645) -> _ReceiptRuleActionConfig_c996e325:
@@ -88,6 +115,41 @@ class AddHeaderProps:
         :param value: (experimental) The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\\r" or "\\n").
 
         :stability: experimental
+        :exampleMetadata: infused
+
+        Example::
+
+            import monocdk as s3
+            import monocdk as actions
+            
+            
+            bucket = s3.Bucket(self, "Bucket")
+            topic = sns.Topic(self, "Topic")
+            
+            ses.ReceiptRuleSet(self, "RuleSet",
+                rules=[s3.aws_ses.ReceiptRuleOptions(
+                    recipients=["hello@aws.com"],
+                    actions=[
+                        actions.AddHeader(
+                            name="X-Special-Header",
+                            value="aws"
+                        ),
+                        actions.S3(
+                            bucket=bucket,
+                            object_key_prefix="emails/",
+                            topic=topic
+                        )
+                    ]
+                ), s3.aws_ses.ReceiptRuleOptions(
+                    recipients=["aws.com"],
+                    actions=[
+                        actions.Sns(
+                            topic=topic
+                        )
+                    ]
+                )
+                ]
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
@@ -138,6 +200,25 @@ class Bounce(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_ses_actions.Bounce"
     '''(experimental) Rejects the received email by returning a bounce response to the sender and, optionally, publishes a notification to Amazon SNS.
 
     :stability: experimental
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        from monocdk import aws_ses_actions as ses_actions
+        from monocdk import aws_sns as sns
+        
+        # bounce_template: ses_actions.BounceTemplate
+        # topic: sns.Topic
+        
+        bounce = ses_actions.Bounce(
+            sender="sender",
+            template=bounce_template,
+        
+            # the properties below are optional
+            topic=topic
+        )
     '''
 
     def __init__(
@@ -156,7 +237,7 @@ class Bounce(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_ses_actions.Bounce"
         '''
         props = BounceProps(sender=sender, template=template, topic=topic)
 
-        jsii.create(Bounce, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="bind")
     def bind(self, _rule: _IReceiptRule_77e30645) -> _ReceiptRuleActionConfig_c996e325:
@@ -189,6 +270,25 @@ class BounceProps:
         :param topic: (experimental) The SNS topic to notify when the bounce action is taken. Default: no notification
 
         :stability: experimental
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            from monocdk import aws_ses_actions as ses_actions
+            from monocdk import aws_sns as sns
+            
+            # bounce_template: ses_actions.BounceTemplate
+            # topic: sns.Topic
+            
+            bounce_props = ses_actions.BounceProps(
+                sender="sender",
+                template=bounce_template,
+            
+                # the properties below are optional
+                topic=topic
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "sender": sender,
@@ -250,6 +350,15 @@ class BounceTemplate(
     '''(experimental) A bounce template.
 
     :stability: experimental
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        from monocdk import aws_ses_actions as ses_actions
+        
+        bounce_template = ses_actions.BounceTemplate.MAILBOX_DOES_NOT_EXIST
     '''
 
     def __init__(
@@ -270,7 +379,7 @@ class BounceTemplate(
             message=message, smtp_reply_code=smtp_reply_code, status_code=status_code
         )
 
-        jsii.create(BounceTemplate, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.python.classproperty # type: ignore[misc]
     @jsii.member(jsii_name="MAILBOX_DOES_NOT_EXIST")
@@ -345,6 +454,21 @@ class BounceTemplateProps:
         :param status_code: (experimental) The SMTP enhanced status code, as defined by RFC 3463.
 
         :stability: experimental
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            from monocdk import aws_ses_actions as ses_actions
+            
+            bounce_template_props = ses_actions.BounceTemplateProps(
+                message="message",
+                smtp_reply_code="smtpReplyCode",
+            
+                # the properties below are optional
+                status_code="statusCode"
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "message": message,
@@ -420,6 +544,26 @@ class Lambda(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_ses_actions.Lambda"
     '''(experimental) Calls an AWS Lambda function, and optionally, publishes a notification to Amazon SNS.
 
     :stability: experimental
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        from monocdk import aws_lambda as lambda_
+        from monocdk import aws_ses_actions as ses_actions
+        from monocdk import aws_sns as sns
+        
+        # function_: lambda.Function
+        # topic: sns.Topic
+        
+        lambda_ = ses_actions.Lambda(
+            function=function_,
+        
+            # the properties below are optional
+            invocation_type=ses_actions.LambdaInvocationType.EVENT,
+            topic=topic
+        )
     '''
 
     def __init__(
@@ -440,7 +584,7 @@ class Lambda(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_ses_actions.Lambda"
             function=function, invocation_type=invocation_type, topic=topic
         )
 
-        jsii.create(Lambda, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="bind")
     def bind(self, rule: _IReceiptRule_77e30645) -> _ReceiptRuleActionConfig_c996e325:
@@ -500,6 +644,26 @@ class LambdaProps:
         :param topic: (experimental) The SNS topic to notify when the Lambda action is taken. Default: no notification
 
         :stability: experimental
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            from monocdk import aws_lambda as lambda_
+            from monocdk import aws_ses_actions as ses_actions
+            from monocdk import aws_sns as sns
+            
+            # function_: lambda.Function
+            # topic: sns.Topic
+            
+            lambda_props = ses_actions.LambdaProps(
+                function=function_,
+            
+                # the properties below are optional
+                invocation_type=ses_actions.LambdaInvocationType.EVENT,
+                topic=topic
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "function": function,
@@ -558,6 +722,41 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_ses_actions.S3"):
     '''(experimental) Saves the received message to an Amazon S3 bucket and, optionally, publishes a notification to Amazon SNS.
 
     :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        import monocdk as s3
+        import monocdk as actions
+        
+        
+        bucket = s3.Bucket(self, "Bucket")
+        topic = sns.Topic(self, "Topic")
+        
+        ses.ReceiptRuleSet(self, "RuleSet",
+            rules=[s3.aws_ses.ReceiptRuleOptions(
+                recipients=["hello@aws.com"],
+                actions=[
+                    actions.AddHeader(
+                        name="X-Special-Header",
+                        value="aws"
+                    ),
+                    actions.S3(
+                        bucket=bucket,
+                        object_key_prefix="emails/",
+                        topic=topic
+                    )
+                ]
+            ), s3.aws_ses.ReceiptRuleOptions(
+                recipients=["aws.com"],
+                actions=[
+                    actions.Sns(
+                        topic=topic
+                    )
+                ]
+            )
+            ]
+        )
     '''
 
     def __init__(
@@ -583,7 +782,7 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_ses_actions.S3"):
             topic=topic,
         )
 
-        jsii.create(S3, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="bind")
     def bind(self, rule: _IReceiptRule_77e30645) -> _ReceiptRuleActionConfig_c996e325:
@@ -623,6 +822,41 @@ class S3Props:
         :param topic: (experimental) The SNS topic to notify when the S3 action is taken. Default: no notification
 
         :stability: experimental
+        :exampleMetadata: infused
+
+        Example::
+
+            import monocdk as s3
+            import monocdk as actions
+            
+            
+            bucket = s3.Bucket(self, "Bucket")
+            topic = sns.Topic(self, "Topic")
+            
+            ses.ReceiptRuleSet(self, "RuleSet",
+                rules=[s3.aws_ses.ReceiptRuleOptions(
+                    recipients=["hello@aws.com"],
+                    actions=[
+                        actions.AddHeader(
+                            name="X-Special-Header",
+                            value="aws"
+                        ),
+                        actions.S3(
+                            bucket=bucket,
+                            object_key_prefix="emails/",
+                            topic=topic
+                        )
+                    ]
+                ), s3.aws_ses.ReceiptRuleOptions(
+                    recipients=["aws.com"],
+                    actions=[
+                        actions.Sns(
+                            topic=topic
+                        )
+                    ]
+                )
+                ]
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "bucket": bucket,
@@ -694,6 +928,41 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_ses_actions.Sns"):
     '''(experimental) Publishes the email content within a notification to Amazon SNS.
 
     :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        import monocdk as s3
+        import monocdk as actions
+        
+        
+        bucket = s3.Bucket(self, "Bucket")
+        topic = sns.Topic(self, "Topic")
+        
+        ses.ReceiptRuleSet(self, "RuleSet",
+            rules=[s3.aws_ses.ReceiptRuleOptions(
+                recipients=["hello@aws.com"],
+                actions=[
+                    actions.AddHeader(
+                        name="X-Special-Header",
+                        value="aws"
+                    ),
+                    actions.S3(
+                        bucket=bucket,
+                        object_key_prefix="emails/",
+                        topic=topic
+                    )
+                ]
+            ), s3.aws_ses.ReceiptRuleOptions(
+                recipients=["aws.com"],
+                actions=[
+                    actions.Sns(
+                        topic=topic
+                    )
+                ]
+            )
+            ]
+        )
     '''
 
     def __init__(
@@ -710,7 +979,7 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_ses_actions.Sns"):
         '''
         props = SnsProps(topic=topic, encoding=encoding)
 
-        jsii.create(Sns, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="bind")
     def bind(self, _rule: _IReceiptRule_77e30645) -> _ReceiptRuleActionConfig_c996e325:
@@ -741,6 +1010,41 @@ class SnsProps:
         :param encoding: (experimental) The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
 
         :stability: experimental
+        :exampleMetadata: infused
+
+        Example::
+
+            import monocdk as s3
+            import monocdk as actions
+            
+            
+            bucket = s3.Bucket(self, "Bucket")
+            topic = sns.Topic(self, "Topic")
+            
+            ses.ReceiptRuleSet(self, "RuleSet",
+                rules=[s3.aws_ses.ReceiptRuleOptions(
+                    recipients=["hello@aws.com"],
+                    actions=[
+                        actions.AddHeader(
+                            name="X-Special-Header",
+                            value="aws"
+                        ),
+                        actions.S3(
+                            bucket=bucket,
+                            object_key_prefix="emails/",
+                            topic=topic
+                        )
+                    ]
+                ), s3.aws_ses.ReceiptRuleOptions(
+                    recipients=["aws.com"],
+                    actions=[
+                        actions.Sns(
+                            topic=topic
+                        )
+                    ]
+                )
+                ]
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "topic": topic,
@@ -786,6 +1090,20 @@ class Stop(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_ses_actions.Stop"):
     '''(experimental) Terminates the evaluation of the receipt rule set and optionally publishes a notification to Amazon SNS.
 
     :stability: experimental
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        from monocdk import aws_ses_actions as ses_actions
+        from monocdk import aws_sns as sns
+        
+        # topic: sns.Topic
+        
+        stop = ses_actions.Stop(
+            topic=topic
+        )
     '''
 
     def __init__(self, *, topic: typing.Optional[_ITopic_465e36b9] = None) -> None:
@@ -796,7 +1114,7 @@ class Stop(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_ses_actions.Stop"):
         '''
         props = StopProps(topic=topic)
 
-        jsii.create(Stop, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="bind")
     def bind(self, _rule: _IReceiptRule_77e30645) -> _ReceiptRuleActionConfig_c996e325:
@@ -821,6 +1139,20 @@ class StopProps:
         :param topic: (experimental) The SNS topic to notify when the stop action is taken.
 
         :stability: experimental
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            from monocdk import aws_ses_actions as ses_actions
+            from monocdk import aws_sns as sns
+            
+            # topic: sns.Topic
+            
+            stop_props = ses_actions.StopProps(
+                topic=topic
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if topic is not None:
